package umlproblemanalysis.integration;

import java.util.List;

import org.eclipse.core.runtime.Status;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.eclipse.uml2.uml.Activity;

import eu.sensoria_ist.casetool.core.ext.SensoriaTool;
import eu.sensoria_ist.casetool.core.ext.SensoriaToolFunction;
import eu.sensoria_ist.casetool.core.ext.SensoriaToolFunctionParameter;
import eu.sensoria_ist.casetool.core.ext.SensoriaToolFunctionReturns;

import umlproblemanalysis.Activator;
import umlproblemanalysis.popup.actions.ProblemAnalysis;
import umlproblemanalysis.popup.actions.ProblemReport;
import umlproblemanalysis.views.ProblemView;

@SensoriaTool(name= "UML Problem Analysis Service", categories= "Analysis", description= "Analysis problems in UML activity diagrams")
public class UMLProblemAnalysisService {

	@SensoriaToolFunction(description= "Analysis UML activity diagrams for problems")
	@SensoriaToolFunctionReturns(description= "A problem report")
	public ProblemReport analyseUML(@SensoriaToolFunctionParameter(description= "A list of UML activities") List<Activity> activities) {
		return ProblemAnalysis.perform(activities);
	}

	@SensoriaToolFunction(description= "Generates a serializeable representation of the problem report")
	@SensoriaToolFunctionReturns(description= "A string")
	public String serializeProblemReport(@SensoriaToolFunctionParameter(description= "A problem report") ProblemReport report) {
		return report.serialize();
	}

	@SensoriaToolFunction(description= "Shows a problem report to the user")
	public void showReportInUI(@SensoriaToolFunctionParameter(description= "A problem report") final ProblemReport report) {
		Display.getDefault().asyncExec(new Runnable() {
			@Override
			public void run() {
				try {
					ProblemView pv= (ProblemView) PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage().showView(
							"umlproblemanalysis.views.ProblemView");
					pv.setProblemReport(report);
				} catch (PartInitException e) {
					Activator.getDefault().getLog().log(new Status(Status.ERROR, Activator.PLUGIN_ID, "Problem opening report", e));
				}
			}
		});
	}

}
