package umlproblemanalysis.popup.actions;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.uml2.uml.Activity;
import org.eclipse.uml2.uml.ActivityNode;
import org.eclipse.uml2.uml.StructuredActivityNode;

public class Problem {
	
	public static enum ProblemCode {
		WRONGCONTROLFLOWSPLIT, WRONGCONTROLFLOWMERGE, RETURNNOTTODECISION
	}
	
	private Activity fActivity;
	
	private ActivityNode fProblemNode;
	
	private List<ActivityNode> fTrace;
	
	private ProblemCode fProblemCode;

	public Problem(Activity activity, ActivityNode problemNode, List<ActivityNode> visitedNodes, ProblemCode problemCode) {
		fActivity= activity;
		fProblemNode= problemNode;
		fTrace= new ArrayList<ActivityNode>(visitedNodes);
		fTrace.add(problemNode);
		fProblemCode= problemCode;
	}
	
	public Activity getActivity() {
		return fActivity;
	}
	
	public ActivityNode getProblemNode() {
		return fProblemNode;
	}
	
	public List<ActivityNode> getTrace() {
		return fTrace;
	}
	
	public ProblemCode getProblemCode() {
		return fProblemCode;
	}

	public String getTraceAsString() {
		StringBuilder b= new StringBuilder();
		if (!fTrace.isEmpty() && ((fTrace.get(0) instanceof StructuredActivityNode)))
			b.append("(Inner Node)");
		for (ActivityNode trace : fTrace) {
			b.append(" -> " + trace.getName());
			
		}
		return b.toString();
	}

	@Override
	public int hashCode() {
		final int prime= 31;
		int result= 1;
		result= prime * result + ( (fActivity == null) ? 0 : fActivity.hashCode());
		result= prime * result + ( (fProblemCode == null) ? 0 : fProblemCode.hashCode());
		result= prime * result + ( (fProblemNode == null) ? 0 : fProblemNode.hashCode());
		result= prime * result + ( (fTrace == null) ? 0 : fTrace.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Problem other= (Problem) obj;
		if (fActivity == null) {
			if (other.fActivity != null)
				return false;
		} else if (!fActivity.equals(other.fActivity))
			return false;
		if (fProblemCode == null) {
			if (other.fProblemCode != null)
				return false;
		} else if (!fProblemCode.equals(other.fProblemCode))
			return false;
		if (fProblemNode == null) {
			if (other.fProblemNode != null)
				return false;
		} else if (!fProblemNode.equals(other.fProblemNode))
			return false;
		if (fTrace == null) {
			if (other.fTrace != null)
				return false;
		} else if (!fTrace.equals(other.fTrace))
			return false;
		return true;
	}
	
	
	

}
