package umlproblemanalysis.popup.actions;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.Status;
import org.eclipse.emf.common.util.TreeIterator;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IActionDelegate;
import org.eclipse.ui.IObjectActionDelegate;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.PartInitException;
import org.eclipse.uml2.uml.Activity;

import umlproblemanalysis.Activator;
import umlproblemanalysis.views.ProblemView;


public class ProblemCheckAction implements IObjectActionDelegate {

	private ISelection selection;

	private IWorkbenchPart targetPart;

	/**
	 * Constructor for Action1.
	 */
	public ProblemCheckAction() {
		super();
	}

	/**
	 * @see IObjectActionDelegate#setActivePart(IAction, IWorkbenchPart)
	 */
	public void setActivePart(IAction action, IWorkbenchPart targetPart) {
		this.targetPart= targetPart;
	}

	/**
	 * @see IActionDelegate#run(IAction)
	 */
	public void run(IAction action) {

		IFile theUMLFile= (IFile) ((IStructuredSelection) selection).getFirstElement();

		ResourceSet set= new ResourceSetImpl();
		Resource resource= set.getResource(URI.createFileURI(theUMLFile.getLocation().toString()), true);

		List<Activity> activities= new ArrayList<Activity>();
		TreeIterator<EObject> allContents= resource.getAllContents();
		while (allContents.hasNext()) {
			EObject next= allContents.next();
			if (next instanceof Activity) {
				activities.add((Activity) next);
			}
		}

		// Problem report.
		ProblemReport report= ProblemAnalysis.perform(activities);

		try {
			ProblemView view= (ProblemView) targetPart.getSite().getPage().showView("umlproblemanalysis.views.ProblemView");
			view.setProblemReport(report);

		} catch (PartInitException e) {
			Activator.getDefault().getLog().log(new Status(Status.ERROR, Activator.PLUGIN_ID, "Problem opening view", e));
		}

	}

	/**
	 * @see IActionDelegate#selectionChanged(IAction, ISelection)
	 */
	public void selectionChanged(IAction action, ISelection selection) {
		this.selection= selection;
	}

}
