package umlproblemanalysis.views;


import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ILabelProviderListener;
import org.eclipse.jface.viewers.IStructuredContentProvider;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.TableColumn;
import org.eclipse.ui.part.ViewPart;

import umlproblemanalysis.popup.actions.Problem;
import umlproblemanalysis.popup.actions.ProblemReport;


public class ProblemView extends ViewPart {

	private TableViewer fProblemViewer;

	class ViewContentProvider implements IStructuredContentProvider {
		public void inputChanged(Viewer v, Object oldInput, Object newInput) {
		}

		public void dispose() {
		}

		public Object[] getElements(Object parent) {
			return ((ProblemReport) parent).getProblems().toArray();
		}
	}

	class ViewLabelProvider implements ITableLabelProvider {
		public String getColumnText(Object obj, int index) {
			
			Problem p= (Problem) obj;
			
			switch (index) {
				case 0: return p.getProblemCode().name();
				case 1: return p.getActivity().getName();
				case 2: return p.getProblemNode().getName();
				case 3: return p.getTraceAsString();
			}
			
			return null;
		}

		public Image getColumnImage(Object obj, int index) {
			return null;
		}

		@Override
		public void addListener(ILabelProviderListener listener) {
		}

		@Override
		public void dispose() {
		}

		@Override
		public boolean isLabelProperty(Object element, String property) {
			return false;
		}

		@Override
		public void removeListener(ILabelProviderListener listener) {
		}
	}

	public void createPartControl(Composite parent) {
		fProblemViewer= new TableViewer(parent, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL);
		fProblemViewer.setContentProvider(new ViewContentProvider());
		fProblemViewer.setLabelProvider(new ViewLabelProvider());
		
		fProblemViewer.getTable().setHeaderVisible(true);
		fProblemViewer.getTable().setLinesVisible(true);
		
		TableColumn col1= new TableColumn(fProblemViewer.getTable(), SWT.LEFT);
		col1.setText("Problem");
		col1.setWidth(200);
		
		TableColumn col2= new TableColumn(fProblemViewer.getTable(), SWT.LEFT);
		col2.setText("Activity");
		col2.setWidth(200);
		
		TableColumn col3= new TableColumn(fProblemViewer.getTable(), SWT.LEFT);
		col3.setText("Problem Node");
		col3.setWidth(200);
		
		TableColumn col4= new TableColumn(fProblemViewer.getTable(), SWT.LEFT);
		col4.setText("Trace");
		col4.setWidth(500);
	}

	public void setFocus() {
		fProblemViewer.getControl().setFocus();
	}

	public void setProblemReport(ProblemReport report) {
		fProblemViewer.setInput(report);
		if (report.getProblems().isEmpty())
			MessageDialog.openInformation(getSite().getShell(), "No problems", "No problems in input file.");
	}
}
